pub struct RelatedEventChain { /* private fields */ }Expand description
A tracker for the chain of entities an event is propagating through, with relationship context.
Implementations
Sourceimpl RelatedEventChain
impl RelatedEventChain
Sourcepub fn next(&self) -> Self
pub fn next(&self) -> Self
Creates a new chain targetting the next target entity. Panics if there is no next target.
Sourcepub fn get_trigger(&self) -> EntityComponentTrigger
pub fn get_trigger(&self) -> EntityComponentTrigger
Creates a new trigger for the current event target with what should be its relationship component.
Sourcepub fn event_target(&self) -> Entity
pub fn event_target(&self) -> Entity
Returns the current event target entity.
Sourcepub fn event_target_mut(&mut self) -> &mut Entity
pub fn event_target_mut(&mut self) -> &mut Entity
Returns a mutable reference to the current event target entity.
Sourcepub fn reversed(&self) -> Self
pub fn reversed(&self) -> Self
Creates a new RelatedEventChain with the targets in reverse order. The current target and the final relationship target remain the same.